package App::duino;
{
  $App::duino::VERSION = '0.05';
}

use strict;
use warnings;

use App::Cmd::Setup -app;

=head1 NAME

App::duino - Command-line tool for working with Arduino

=head1 VERSION

version 0.05

=head1 SYNOPSIS

   $ duino help

=head1 AUTHOR

Alessandro Ghedini <alexbio@cpan.org>

=head1 LICENSE AND COPYRIGHT

Copyright 2013 Alessandro Ghedini.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut

1; # End of App::duino
